# About NEAT schema

This project defines the schema in the form of a [YAML file](https://github.com/Knowledge-Graph-Hub/neat_ml_schema/blob/main/src/schema/neat_ml_schema.yaml) for data going into graph ML pipelines (specifically [NEAT](https://github.com/Knowledge-Graph-Hub/NEAT)). NEAT schema itself is generated from a [linkML](https://github.com/linkml/linkml) template.
